@@ -24,6 +24,8 @@
 #include <QtOpenGL/qopengltextureblitter.h>
 #include <QtOpenGL/qopenglvertexarrayobject.h>
 #include <QtOpenGL/qopenglwindow.h>
+
+QT_BEGIN_NAMESPACE
 class QAbstractOpenGLFunctions;
 class QOpenGLFramebufferObjectFormat;
 class QOpenGLFunctions_1_0;
@@ -59,6 +61,7 @@ class QOpenGLTimeMonitor;
 class QOpenGLTimerQuery;
 class QOpenGLVersionFunctionsFactory;
 class QOpenGLVersionProfile;
+QT_END_NAMESPACE
 
 // Type indices
 enum [[deprecated]] : int {
@@ -237,6 +240,9 @@ enum : int {
 // This variable stores all Python types exported by this module.
 extern Shiboken::Module::TypeInitStruct *SbkPySide6_QtOpenGLTypeStructs;
 
+// This variable stores all Python types exported by this module in a backwards compatible way with identical indexing.
+[[deprecated]] extern PyTypeObject **SbkPySide6_QtOpenGLTypes;
+
 // This variable stores the Python module object exported by this module.
 extern PyObject *SbkPySide6_QtOpenGLModuleObject;
 
@@ -246,21 +252,19 @@ extern SbkConverter **SbkPySide6_QtOpenGLTypeConverters;
 // Converter indices
 enum [[deprecated]] : int {
     SBK_QTOPENGL_QLIST_INT_IDX                               = 0, // QList<int>
-    SBK_QTOPENGL_STD_PAIR_INT_INT_IDX                        = 2, // std::pair<int,int>
-    SBK_QTOPENGL_STD_PAIR_FLOAT_FLOAT_IDX                    = 4, // std::pair<float,float>
-    SBK_QTOPENGL_STD_PAIR_QOPENGLTEXTURE_FILTER_QOPENGLTEXTURE_FILTER_IDX = 6, // std::pair<QOpenGLTexture::Filter,QOpenGLTexture::Filter>
-    SBK_QTOPENGL_QLIST_QSIZE_IDX                             = 8, // QList<QSize>
-    SBK_QTOPENGL_QLIST_UNSIGNEDINT_IDX                       = 10, // QList<unsigned int>
-    SBK_QTOPENGL_QLIST_QOBJECTPTR_IDX                        = 12, // QList<QObject*>
-    SBK_QTOPENGL_QLIST_QBYTEARRAY_IDX                        = 14, // QList<QByteArray>
-    SBK_QTOPENGL_QLIST_UINT64_T_IDX                          = 16, // QList<uint64_t>
-    SBK_QTOPENGL_QLIST_FLOAT_IDX                             = 18, // QList<float>
-    SBK_QTOPENGL_QLIST_QOPENGLSHADERPTR_IDX                  = 20, // QList<QOpenGLShader*>
-    SBK_QTOPENGL_QLIST_QOPENGLDEBUGMESSAGE_IDX               = 22, // QList<QOpenGLDebugMessage>
-    SBK_QTOPENGL_QLIST_QVARIANT_IDX                          = 24, // QList<QVariant>
-    SBK_QTOPENGL_QLIST_QSTRING_IDX                           = 26, // QList<QString>
-    SBK_QTOPENGL_QMAP_QSTRING_QVARIANT_IDX                   = 28, // QMap<QString,QVariant>
-    SBK_QTOPENGL_CONVERTERS_IDX_COUNT                        = 30,
+    SBK_QTOPENGL_STD_PAIR_INT_INT_IDX                        = 1, // std::pair<int,int>
+    SBK_QTOPENGL_STD_PAIR_FLOAT_FLOAT_IDX                    = 2, // std::pair<float,float>
+    SBK_QTOPENGL_STD_PAIR_QOPENGLTEXTURE_FILTER_QOPENGLTEXTURE_FILTER_IDX = 3, // std::pair<QOpenGLTexture::Filter,QOpenGLTexture::Filter>
+    SBK_QTOPENGL_QLIST_QSIZE_IDX                             = 4, // QList<QSize>
+    SBK_QTOPENGL_QLIST_UNSIGNEDINT_IDX                       = 5, // QList<unsigned int>
+    SBK_QTOPENGL_QLIST_UINT64_T_IDX                          = 6, // QList<uint64_t>
+    SBK_QTOPENGL_QLIST_FLOAT_IDX                             = 7, // QList<float>
+    SBK_QTOPENGL_QLIST_QOPENGLSHADERPTR_IDX                  = 8, // QList<QOpenGLShader*>
+    SBK_QTOPENGL_QLIST_QOPENGLDEBUGMESSAGE_IDX               = 9, // QList<QOpenGLDebugMessage>
+    SBK_QTOPENGL_QLIST_QVARIANT_IDX                          = 10, // QList<QVariant>
+    SBK_QTOPENGL_QLIST_QSTRING_IDX                           = 11, // QList<QString>
+    SBK_QTOPENGL_QMAP_QSTRING_QVARIANT_IDX                   = 12, // QMap<QString,QVariant>
+    SBK_QTOPENGL_CONVERTERS_IDX_COUNT                        = 13,
 };
 
 // Converter indices
@@ -271,16 +275,14 @@ enum : int {
     SBK_QtOpenGL_std_pair_QOpenGLTexture_Filter_QOpenGLTexture_Filter_IDX = 3, // std::pair<QOpenGLTexture::Filter,QOpenGLTexture::Filter>
     SBK_QtOpenGL_QList_QSize_IDX                             = 4, // QList<QSize>
     SBK_QtOpenGL_QList_unsignedint_IDX                       = 5, // QList<unsigned int>
-    SBK_QtOpenGL_QList_QObjectPTR_IDX                        = 6, // QList<QObject*>
-    SBK_QtOpenGL_QList_QByteArray_IDX                        = 7, // QList<QByteArray>
-    SBK_QtOpenGL_QList_uint64_t_IDX                          = 8, // QList<uint64_t>
-    SBK_QtOpenGL_QList_float_IDX                             = 9, // QList<float>
-    SBK_QtOpenGL_QList_QOpenGLShaderPTR_IDX                  = 10, // QList<QOpenGLShader*>
-    SBK_QtOpenGL_QList_QOpenGLDebugMessage_IDX               = 11, // QList<QOpenGLDebugMessage>
-    SBK_QtOpenGL_QList_QVariant_IDX                          = 12, // QList<QVariant>
-    SBK_QtOpenGL_QList_QString_IDX                           = 13, // QList<QString>
-    SBK_QtOpenGL_QMap_QString_QVariant_IDX                   = 14, // QMap<QString,QVariant>
-    SBK_QtOpenGL_CONVERTERS_IDX_COUNT                        = 15,
+    SBK_QtOpenGL_QList_uint64_t_IDX                          = 6, // QList<uint64_t>
+    SBK_QtOpenGL_QList_float_IDX                             = 7, // QList<float>
+    SBK_QtOpenGL_QList_QOpenGLShaderPTR_IDX                  = 8, // QList<QOpenGLShader*>
+    SBK_QtOpenGL_QList_QOpenGLDebugMessage_IDX               = 9, // QList<QOpenGLDebugMessage>
+    SBK_QtOpenGL_QList_QVariant_IDX                          = 10, // QList<QVariant>
+    SBK_QtOpenGL_QList_QString_IDX                           = 11, // QList<QString>
+    SBK_QtOpenGL_QMap_QString_QVariant_IDX                   = 12, // QMap<QString,QVariant>
+    SBK_QtOpenGL_CONVERTERS_IDX_COUNT                        = 13,
 };
 // Macros for type check
 
