@@ -8,10 +8,10 @@ pyside_library_soversion = "6.10"
 version = "6.10.1"
 version_info = (6, 10, 1, "", "")
 
-__build_date__ = '2025-11-27T09:13:02+00:00'
-__build_commit_date__ = '2025-11-20T20:32:52+00:00'
-__build_commit_hash__ = '9846d593ab028c46c49fba8dc3d78f3b75df4484'
-__build_commit_hash_described__ = '6.10.1-1'
+__build_date__ = '2025-12-17T17:37:07+00:00'
+
+
+
 
 
 
